@@ -1,12 +1,11 @@
 #' @title
 #' Generate stopping condition.
 #'
-#' @description
-#' Wrap a function within a stopping condition object.
+#' @description Wrap a function within a stopping condition object.
 #'
 #' @param condition.fun [\code{function}]\cr
-#'   Function which takes an environment \code{\link[ParamHelpers]{OptPath}} as its
-#'   only parameter and return a single logical.
+#'   Function which takes a logger object \code{log} (see \code{\link{initLogger}})
+#'   and returns a single logical.
 #' @param name [\code{character(1)}]\cr
 #'   Identifier for the stopping condition.
 #' @param message [\code{character(1)}]\cr
@@ -15,7 +14,7 @@
 #' @return [\code{ecr_terminator}]
 #' @export
 makeTerminator = function(condition.fun, name, message) {
-  assertFunction(condition.fun, args = c("opt.state"))
+  assertFunction(condition.fun, args = "log")
   assertCharacter(name, len = 1L, any.missing = FALSE)
   assertCharacter(message, len = 1L, any.missing = FALSE)
 
